"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.20.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.phone_home_bundle_api_telemetry import PhoneHomeBundleApiTelemetry
from delphix.api.gateway.model.phone_home_bundle_product_info import PhoneHomeBundleProductInfo
from delphix.api.gateway.model.phone_home_bundle_registered_engine import PhoneHomeBundleRegisteredEngine
globals()['PhoneHomeBundleApiTelemetry'] = PhoneHomeBundleApiTelemetry
globals()['PhoneHomeBundleProductInfo'] = PhoneHomeBundleProductInfo
globals()['PhoneHomeBundleRegisteredEngine'] = PhoneHomeBundleRegisteredEngine
from delphix.api.gateway.model.phone_home_bundle import PhoneHomeBundle


class TestPhoneHomeBundle(unittest.TestCase):
    """PhoneHomeBundle unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPhoneHomeBundle(self):
        """Test PhoneHomeBundle"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PhoneHomeBundle()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
