"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.20.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.cdbs_api import CDBsApi  # noqa: E501


class TestCDBsApi(unittest.TestCase):
    """CDBsApi unit test stubs"""

    def setUp(self):
        self.api = CDBsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_cdb(self):
        """Test case for attach_cdb

        Attach an Oracle CDB to an Oracle database.  # noqa: E501
        """
        pass

    def test_create_cdb_tags(self):
        """Test case for create_cdb_tags

        Create tags for a CDB.  # noqa: E501
        """
        pass

    def test_delete_cdb(self):
        """Test case for delete_cdb

        Delete a CDB.  # noqa: E501
        """
        pass

    def test_delete_cdb_tags(self):
        """Test case for delete_cdb_tags

        Delete tags for a CDB.  # noqa: E501
        """
        pass

    def test_detach_cdb(self):
        """Test case for detach_cdb

        Detaches an Oracle CDB from an Oracle database.  # noqa: E501
        """
        pass

    def test_disable_cdb(self):
        """Test case for disable_cdb

        Disable a CDB.  # noqa: E501
        """
        pass

    def test_enable_cdb(self):
        """Test case for enable_cdb

        Enable a CDB.  # noqa: E501
        """
        pass

    def test_get_cdb_by_id(self):
        """Test case for get_cdb_by_id

        Get a CDB by ID (Oracle only).  # noqa: E501
        """
        pass

    def test_get_cdb_deletion_dependencies(self):
        """Test case for get_cdb_deletion_dependencies

        Get deletion dependencies of a CDB.  # noqa: E501
        """
        pass

    def test_get_cdbs(self):
        """Test case for get_cdbs

        List all CDBs (Oracle only).  # noqa: E501
        """
        pass

    def test_get_tags_cdb(self):
        """Test case for get_tags_cdb

        Get tags for a CDB.  # noqa: E501
        """
        pass

    def test_search_cdbs(self):
        """Test case for search_cdbs

        Search for CDBs (Oracle only).  # noqa: E501
        """
        pass

    def test_update_cdb(self):
        """Test case for update_cdb

        Update a CDB.  # noqa: E501
        """
        pass

    def test_update_cdb_by_id(self):
        """Test case for update_cdb_by_id

        Update a CDB.  # noqa: E501
        """
        pass

    def test_upgrade_cdb(self):
        """Test case for upgrade_cdb

        Upgrade Oracle CDB  # noqa: E501
        """
        pass

    def test_verify_cdb_jdbc_connection_string(self):
        """Test case for verify_cdb_jdbc_connection_string

        Verify JDBC connection string for a CDB.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
